@@ -45,7 +45,7 @@ test.impute2xxx_large <- function()
 	prD2 <- (dim(fvprob)[2])/2
 	checkEqualsNumeric(prD2,dim(fvdose)[2])
 	
-	rm(fvdose,fvprob);gc()
+	rm(list=ls());gc()
 	
 	unlink("*.fv?")
 	unlink("tmp*")
